@@ -8,9 +8,9 @@ use Log::ger;
 use Sort::Sub ();
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-04-17'; # DATE
+our $DATE = '2023-06-06'; # DATE
 our $DIST = 'App-FirefoxMultiAccountContainersUtils'; # DIST
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 $Sort::Sub::argsopt_sortsub{sort_sub}{cmdline_aliases} = {S=>{}};
 $Sort::Sub::argsopt_sortsub{sort_args}{cmdline_aliases} = {A=>{}};
@@ -460,6 +460,16 @@ _
             pos => 1,
             slurpy => 1,
         },
+        extra_firefox_options_before => {
+            summary => 'Additional options (arguments) to put before the URLs',
+            schema => ['array*', of=>'str*'],
+            cmdline_aliases => {'b'=>{}},
+        },
+        extra_firefox_options_after => {
+            summary => 'Additional options (arguments) to put after the URLs',
+            schema => ['array*', of=>'str*'],
+            cmdline_aliases => {'a'=>{}},
+        },
     },
     features => {
     },
@@ -476,6 +486,17 @@ _
             test => 0,
             'x.doc.show_result' => 0,
         },
+        {
+            summary => 'Open URL in a new tab in a new window',
+            argv => [qw|mycontainer www.example.com -b --new-window|],
+            test => 0,
+            'x.doc.show_result' => 0,
+            description => <<'_',
+
+This command passes the `--new-window` option to `firefox`.
+
+_
+        },
     ],
     links => [
         {url=>'prog:open-browser'},
@@ -495,7 +516,12 @@ sub open_firefox_container {
         push @urls, $url;
     }
 
-    my @cmd = ("firefox", @urls);
+    my @cmd = (
+        "firefox",
+        @{$args{extra_firefox_options_before} // []},
+        @urls,
+        @{$args{extra_firefox_options_after} // []},
+    );
     log_trace "Executing %s ...", \@cmd;
     exec @cmd;
     #[200]; # won't be reached
@@ -516,7 +542,7 @@ App::FirefoxMultiAccountContainersUtils - Utilities related to Firefox Multi-Acc
 
 =head1 VERSION
 
-This document describes version 0.016 of App::FirefoxMultiAccountContainersUtils (from Perl distribution App-FirefoxMultiAccountContainersUtils), released on 2023-04-17.
+This document describes version 0.017 of App::FirefoxMultiAccountContainersUtils (from Perl distribution App-FirefoxMultiAccountContainersUtils), released on 2023-06-06.
 
 =head1 SYNOPSIS
 
@@ -853,6 +879,16 @@ Examples:
 
  open_firefox_container(container => "mycontainer");
 
+=item * Open URL in a new tab in a new window:
+
+ open_firefox_container(
+     container => "mycontainer",
+   urls => ["www.example.com"],
+   extra_firefox_options_before => ["--new-window"]
+ );
+
+This command passes the C<--new-window> option to C<firefox>.
+
 =back
 
 This utility opens a new firefox tab in a specific multi-account container. This
@@ -879,6 +915,14 @@ Arguments ('*' denotes required arguments):
 
 (No description)
 
+=item * B<extra_firefox_options_after> => I<array[str]>
+
+Additional options (arguments) to put after the URLs.
+
+=item * B<extra_firefox_options_before> => I<array[str]>
+
+Additional options (arguments) to put before the URLs.
+
 =item * B<profile> => I<firefox::local_profile_name::default_first>
 
 (No description)
